﻿using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Serilog;
using Stimulsoft.Report;
using Stimulsoft.Report.Angular;
using Stimulsoft.Report.Web;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;

namespace KSInventory.Controllers
{
    [Controller]
    public class ReportViewerController : Controller
    {
        // Activation with using license code
        public ReportViewerController()
        {
            try
            {
                Stimulsoft.Base.StiLicense.Key = "";
            }
            catch (Exception e)
            {
                Log.Error(e.Message);
            }
        }

        // Specify viewer options
        [HttpPost]
        public IActionResult InitViewer()
        {
            var requestParams = StiAngularViewer.GetRequestParams(this);
            var options = new StiAngularViewerOptions();
            options.Actions.GetReport = "GetReport";
            options.Actions.ViewerEvent = "ViewerEvent";
            options.Appearance.ScrollbarsMode = true;
            options.Appearance.ShowPageShadow = true;
            options.Appearance.ShowTooltips = false;
            options.Appearance.InterfaceType = StiInterfaceType.Auto;
            options.Toolbar.ShowOpenButton = false;
            options.Toolbar.ShowAboutButton = false;
            options.Theme = StiViewerTheme.Office2013LightGrayBlue;
            //options.Localization = StiAngularHelper.MapPath(this, "Reports/Localization/th.xml");

            return StiAngularViewer.ViewerDataResult(requestParams, options);
        }

        [HttpPost]
        public IActionResult GetReport()
        {
            Stimulsoft.Base.StiFontCollection.AddResourceFont("angsa.ttf", System.IO.File.ReadAllBytes("Fonts/angsa.ttf"), "ttf", "Angsana New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("angsab.ttf", System.IO.File.ReadAllBytes("Fonts/angsab.ttf"), "ttf", "Angsana New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("angsai.ttf", System.IO.File.ReadAllBytes("Fonts/angsai.ttf"), "ttf", "Angsana New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("angsabi.ttf", System.IO.File.ReadAllBytes("Fonts/angsaz.ttf"), "ttf", "Angsana New");

            Stimulsoft.Base.StiFontCollection.AddResourceFont("THSarabunNew.ttf", System.IO.File.ReadAllBytes("Fonts/THSarabunNew.ttf"), "ttf", "TH Sarabun New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("THSarabunNewB.ttf", System.IO.File.ReadAllBytes("Fonts/THSarabunNew-Bold.ttf"), "ttf", "TH Sarabun New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("THSarabunNewI.ttf", System.IO.File.ReadAllBytes("Fonts/THSarabunNew-Italic.ttf"), "ttf", "TH Sarabun New");
            Stimulsoft.Base.StiFontCollection.AddResourceFont("THSarabunNewBI.ttf", System.IO.File.ReadAllBytes("Fonts/THSarabunNew-Bold-Italic.ttf"), "ttf", "TH Sarabun New");

            var report = StiReport.CreateNewReport();
            var path = StiAngularHelper.MapPath(this, "Reports/Report2.mrt");
            report.Load(path);

            return StiAngularViewer.GetReportResult(this, report);
        }

        [HttpPost]
        public IActionResult ViewerEvent()
        {
            return StiAngularViewer.ViewerEventResult(this);
        }
    }
}
